validator — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »

# validator

Validator classes validate data before their GUI representation is closed by the user. The validator class also takes care of informing the user where the data is invalid.

This prevents the user from entering invalid data into the model or flushing it to the database.

- entity_validator
- object_validator

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »

Comments
blog comments powered by Disqus